You are viewing a plain text version of this content. The canonical link for it is here.
Posted to github@datafusion.apache.org by "andygrove (via GitHub)" <gi...@apache.org> on 2024/11/20 15:04:25 UTC

Re: [PR] chore: Improve CometScan metrics [datafusion-comet]

andygrove commented on PR #1100:
URL: https://github.com/apache/datafusion-comet/pull/1100#issuecomment-2488823931

   @viirya @kazuyukitanimura @comphead Could you take another look? The scope increased slightly (see updated PR description). 
   
   This is what the logging looks like now for native query plans with metrics:
   
   ```
   [Stage 18 Partition 25] plan creation (including CometScans fetching first batches) took 1.490261253s:
   ShuffleWriterExec: partitioning=UnknownPartitioning(1), metrics=[output_rows=10, elapsed_compute=55.574µs, spill_count=0, spilled_bytes=0, data_size=704]
     ScanExec: source=[], schema=[col_0: Int64, col_1: Decimal128(34, 4), col_2: Date32, col_3: Int32], metrics=[output_rows=20, elapsed_compute=1.490176093s, cast_time=1ns]
   ```


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: github-unsubscribe@datafusion.apache.org

For queries about this service, please contact Infrastructure at:
users@infra.apache.org


---------------------------------------------------------------------
To unsubscribe, e-mail: github-unsubscribe@datafusion.apache.org
For additional commands, e-mail: github-help@datafusion.apache.org